@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for transfer service client
 
@@ -10,10 +11,11 @@ Usage::
     client: TransferClient = boto3.client("transfer")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_transfer.paginator import ListServersPaginator
 from mypy_boto3_transfer.type_defs import (
     CreateServerResponseTypeDef,
@@ -224,7 +226,6 @@ class TransferClient:
         [Client.update_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/transfer.html#Transfer.Client.update_user)
         """
 
-    @overload
     def get_paginator(self, operation_name: Literal["list_servers"]) -> ListServersPaginator:
         """
         [Paginator.ListServers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/transfer.html#Transfer.Paginator.ListServers)
