@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for transfer service client paginators.
 
@@ -16,11 +17,11 @@ Usage::
     list_servers_paginator: ListServersPaginator = client.get_paginator("list_servers")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
-from botocore.paginate import Paginator as Boto3Paginator
-from mypy_boto3_transfer.type_defs import ListServersResponseTypeDef, PaginatorConfigTypeDef
+from typing import Iterator
 
+from botocore.paginate import Paginator as Boto3Paginator
+
+from mypy_boto3_transfer.type_defs import ListServersResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListServersPaginator",)
 
